# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PdmObject.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fPdmObject.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\"T\n\x1aPdmDescendantObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x15\n\rchild_keyword\x18\x02 \x01(\t\"M\n\x15PdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\"j\n\x1b\x43reatePdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\x12\x15\n\rclass_keyword\x18\x03 \x01(\t\"Q\n\x16PdmParentObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x16\n\x0eparent_keyword\x18\x02 \x01(\t\"\xc0\x01\n\tPdmObject\x12\x15\n\rclass_keyword\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x04\x12\x33\n\nparameters\x18\x03 \x03(\x0b\x32\x1f.rips.PdmObject.ParametersEntry\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12\x12\n\npersistent\x18\x05 \x01(\x08\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x0ePdmObjectArray\x12 \n\x07objects\x18\x01 \x03(\x0b\x32\x0f.rips.PdmObject\"I\n\x16PdmObjectGetterRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\"[\n\x16PdmObjectSetterRequest\x12-\n\x07request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectGetterRequest\x12\x12\n\ndata_count\x18\x02 \x01(\x05\"\xbf\x01\n\x14PdmObjectSetterChunk\x12\x33\n\x0bset_request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectSetterRequestH\x00\x12$\n\x07\x64oubles\x18\x02 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x03 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x04 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"\x1b\n\x0b\x44oubleArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"\x18\n\x08IntArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"\x1b\n\x0bStringArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\x8a\x01\n\x14PdmObjectGetterReply\x12$\n\x07\x64oubles\x18\x01 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x02 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x03 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"j\n\x16PdmObjectMethodRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x1f\n\x06params\x18\x03 \x01(\x0b\x32\x0f.rips.PdmObject2\xf9\x04\n\x10PdmObjectService\x12S\n\x17GetDescendantPdmObjects\x12 .rips.PdmDescendantObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12I\n\x12GetChildPdmObjects\x12\x1b.rips.PdmChildObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12G\n\x14GetAncestorPdmObject\x12\x1c.rips.PdmParentObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12L\n\x14\x43reateChildPdmObject\x12!.rips.CreatePdmChildObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12\x39\n\x17UpdateExistingPdmObject\x12\x0f.rips.PdmObject\x1a\x0b.rips.Empty\"\x00\x12S\n\x13\x43\x61llPdmObjectGetter\x12\x1c.rips.PdmObjectGetterRequest\x1a\x1a.rips.PdmObjectGetterReply\"\x00\x30\x01\x12V\n\x13\x43\x61llPdmObjectSetter\x12\x1a.rips.PdmObjectSetterChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x12\x46\n\x13\x43\x61llPdmObjectMethod\x12\x1c.rips.PdmObjectMethodRequest\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PdmObject_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PDMOBJECT_PARAMETERSENTRY._options = None
  _PDMOBJECT_PARAMETERSENTRY._serialized_options = b'8\001'
  _globals['_PDMDESCENDANTOBJECTREQUEST']._serialized_start=44
  _globals['_PDMDESCENDANTOBJECTREQUEST']._serialized_end=128
  _globals['_PDMCHILDOBJECTREQUEST']._serialized_start=130
  _globals['_PDMCHILDOBJECTREQUEST']._serialized_end=207
  _globals['_CREATEPDMCHILDOBJECTREQUEST']._serialized_start=209
  _globals['_CREATEPDMCHILDOBJECTREQUEST']._serialized_end=315
  _globals['_PDMPARENTOBJECTREQUEST']._serialized_start=317
  _globals['_PDMPARENTOBJECTREQUEST']._serialized_end=398
  _globals['_PDMOBJECT']._serialized_start=401
  _globals['_PDMOBJECT']._serialized_end=593
  _globals['_PDMOBJECT_PARAMETERSENTRY']._serialized_start=544
  _globals['_PDMOBJECT_PARAMETERSENTRY']._serialized_end=593
  _globals['_PDMOBJECTARRAY']._serialized_start=595
  _globals['_PDMOBJECTARRAY']._serialized_end=645
  _globals['_PDMOBJECTGETTERREQUEST']._serialized_start=647
  _globals['_PDMOBJECTGETTERREQUEST']._serialized_end=720
  _globals['_PDMOBJECTSETTERREQUEST']._serialized_start=722
  _globals['_PDMOBJECTSETTERREQUEST']._serialized_end=813
  _globals['_PDMOBJECTSETTERCHUNK']._serialized_start=816
  _globals['_PDMOBJECTSETTERCHUNK']._serialized_end=1007
  _globals['_DOUBLEARRAY']._serialized_start=1009
  _globals['_DOUBLEARRAY']._serialized_end=1036
  _globals['_INTARRAY']._serialized_start=1038
  _globals['_INTARRAY']._serialized_end=1062
  _globals['_STRINGARRAY']._serialized_start=1064
  _globals['_STRINGARRAY']._serialized_end=1091
  _globals['_PDMOBJECTGETTERREPLY']._serialized_start=1094
  _globals['_PDMOBJECTGETTERREPLY']._serialized_end=1232
  _globals['_PDMOBJECTMETHODREQUEST']._serialized_start=1234
  _globals['_PDMOBJECTMETHODREQUEST']._serialized_end=1340
  _globals['_PDMOBJECTSERVICE']._serialized_start=1343
  _globals['_PDMOBJECTSERVICE']._serialized_end=1976
# @@protoc_insertion_point(module_scope)
