# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Commands.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Case_pb2 as Case__pb2
import Definitions_pb2 as Definitions__pb2
import PdmObject_pb2 as PdmObject__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x43ommands.proto\x12\x04rips\x1a\nCase.proto\x1a\x11\x44\x65\x66initions.proto\x1a\x0fPdmObject.proto\"1\n\x0f\x46ilePathRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x10\n\x08gridOnly\x18\x02 \x01(\x08\"9\n\x12ReplaceCaseRequest\x12\x13\n\x0bnewGridFile\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x61seId\x18\x02 \x01(\x05\"B\n\x13ReplaceCaseRequests\x12+\n\tcasePairs\x18\x01 \x03(\x0b\x32\x18.rips.ReplaceCaseRequest\"F\n\x19ReplaceSourceCasesRequest\x12\x14\n\x0cgridListFile\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61seGroupId\x18\x02 \x01(\x05\".\n\x16\x45xportMultiCaseRequest\x12\x14\n\x0cgridListFile\x18\x01 \x01(\t\"\xb2\x01\n\x16\x45xportSnapshotsRequest\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.rips.SnapshotType\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61seId\x18\x03 \x01(\x05\x12\x0e\n\x06viewId\x18\x04 \x01(\x05\x12\x14\n\x0c\x65xportFolder\x18\x05 \x01(\t\x12\x30\n\x10plotOutputFormat\x18\x06 \x01(\x0e\x32\x16.rips.PlotOutputFormat\"\x8f\x01\n\x15\x45xportPropertyRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x10\n\x08property\x18\x03 \x01(\t\x12\x16\n\x0e\x65\x63lipseKeyword\x18\x04 \x01(\t\x12\x16\n\x0eundefinedValue\x18\x05 \x01(\x01\x12\x12\n\nexportFile\x18\x06 \x01(\t\"W\n\x1c\x45xportPropertyInViewsRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0f\n\x07viewIds\x18\x02 \x03(\x05\x12\x16\n\x0eundefinedValue\x18\x03 \x01(\x01\"\x8b\x03\n\x19\x45xportWellPathCompRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12+\n\tfileSplit\x18\x04 \x01(\x0e\x32\x18.rips.CompdatExportSplit\x12.\n\rcompdatExport\x18\x05 \x01(\x0e\x32\x17.rips.CompdatExportType\x12\x1b\n\x13includePerforations\x18\x06 \x01(\x08\x12\x18\n\x10includeFishbones\x18\x07 \x01(\x08\x12#\n\x1b\x65xcludeMainBoreForFishbones\x18\x08 \x01(\x08\x12\x35\n\x0f\x63ombinationMode\x18\t \x01(\x0e\x32\x1c.rips.CompdatCombinationMode\x12\x16\n\x0e\x63ustomFileName\x18\n \x01(\t\x12\x16\n\x0e\x65xportComments\x18\x0b \x01(\x08\x12\x15\n\rexportWelspec\x18\x0c \x01(\x08\"\xca\x01\n\x1c\x45xportSimWellPathFracRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\x12\x1b\n\x13simulationWellNames\x18\x04 \x03(\t\x12+\n\tfileSplit\x18\x05 \x01(\x0e\x32\x18.rips.CompdatExportSplit\x12.\n\rcompdatExport\x18\x06 \x01(\x0e\x32\x17.rips.CompdatExportType\"4\n\x10\x45xportMswRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08wellPath\x18\x02 \x01(\t\"B\n\x15\x45xportWellPathRequest\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\x12\x12\n\nmdStepSize\x18\x02 \x01(\x01\"\xaf\x01\n\x19\x45xportVisibleCellsRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x15\n\rexportKeyword\x18\x03 \x01(\t\x12\x1f\n\x17visibleActiveCellsValue\x18\x04 \x01(\x05\x12\x1e\n\x16hiddenActiveCellsValue\x18\x05 \x01(\x05\x12\x1a\n\x12inactiveCellsValue\x18\x06 \x01(\x05\"b\n\x16SetExportFolderRequest\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.rips.ExportFolderType\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0c\x63reateFolder\x18\x03 \x01(\x08\"7\n\x16RunOctaveScriptRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61seIds\x18\x02 \x03(\x05\"4\n\x13SetWindowSizeParams\x12\x0e\n\x06height\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\"C\n\x1b\x43omputeCaseGroupStatRequest\x12\x0f\n\x07\x63\x61seIds\x18\x01 \x03(\x05\x12\x13\n\x0b\x63\x61seGroupId\x18\x02 \x01(\x05\"E\n\x11SetTimeStepParams\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\"N\n\x1cScaleFractureTemplateRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nhalfLength\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"L\n\x19SetFracContainmentRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08topLayer\x18\x02 \x01(\x05\x12\x11\n\tbaseLayer\x18\x03 \x01(\x05\"\xee\x01\n\x19\x43reateMultipleFracRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x12\n\ntemplateId\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12\x19\n\x11minDistFromWellTd\x18\x04 \x01(\x01\x12\x1b\n\x13maxFracturesPerWell\x18\x05 \x01(\x05\x12\x10\n\x08topLayer\x18\x06 \x01(\x05\x12\x11\n\tbaseLayer\x18\x07 \x01(\x05\x12\x0f\n\x07spacing\x18\x08 \x01(\x05\x12(\n\x06\x61\x63tion\x18\t \x01(\x0e\x32\x18.rips.MultipleFracAction\"\xb8\x01\n\x17\x43reateLgrForCompRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08timeStep\x18\x02 \x01(\x05\x12\x15\n\rwellPathNames\x18\x03 \x03(\t\x12\x13\n\x0brefinementI\x18\x04 \x01(\x05\x12\x13\n\x0brefinementJ\x18\x05 \x01(\x05\x12\x13\n\x0brefinementK\x18\x06 \x01(\x05\x12%\n\tsplitType\x18\x07 \x01(\x0e\x32\x12.rips.LgrSplitType\",\n\x19\x43reateSatPressPlotRequest\x12\x0f\n\x07\x63\x61seIds\x18\x01 \x03(\x05\"/\n\x1a\x43reateGridCaseGroupRequest\x12\x11\n\tcasePaths\x18\x01 \x03(\t\"2\n\x1b\x43reateStatisticsCaseRequest\x12\x13\n\x0b\x63\x61seGroupId\x18\x01 \x01(\x05\"\xae\x01\n\x15\x45xportFlowInfoRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x11\n\ttimeSteps\x18\x02 \x03(\x05\x12\x11\n\tinjectors\x18\x03 \x03(\t\x12\x11\n\tproducers\x18\x04 \x03(\t\x12\x10\n\x08\x66ileName\x18\x05 \x01(\t\x12\x1c\n\x14minimumCommunication\x18\x06 \x01(\x01\x12\x1c\n\x14\x61quiferCellThreshold\x18\x07 \x01(\x01\"#\n\x11\x43reateViewRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\"\"\n\x10\x43loneViewRequest\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\"r\n\x14\x43reateWbsPlotRequest\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\x12\x10\n\x08wellPath\x18\x02 \x01(\t\x12\x10\n\x08timeStep\x18\x03 \x01(\x05\x12&\n\rwbsParameters\x18\x04 \x01(\x0b\x32\x0f.rips.PdmObject\"G\n\x16ImportWellPathsRequest\x12\x16\n\x0ewellPathFolder\x18\x01 \x01(\t\x12\x15\n\rwellPathFiles\x18\x02 \x03(\t\"H\n\x19ImportWellLogFilesRequest\x12\x15\n\rwellLogFolder\x18\x01 \x01(\t\x12\x14\n\x0cwellLogFiles\x18\x02 \x03(\t\"L\n\x1bImportFormationNamesRequest\x12\x16\n\x0e\x66ormationFiles\x18\x01 \x03(\t\x12\x15\n\rapplyToCaseId\x18\x02 \x01(\x05\"\xea\x01\n\x1c\x45xportWellLogPlotDataRequest\x12(\n\x0c\x65xportFormat\x18\x01 \x01(\x0e\x32\x12.rips.ExportFormat\x12\x0e\n\x06viewId\x18\x02 \x01(\x05\x12\x14\n\x0c\x65xportFolder\x18\x03 \x01(\t\x12\x12\n\nfilePrefix\x18\x04 \x01(\t\x12\x14\n\x0c\x65xportTvdRkb\x18\x05 \x01(\x08\x12\x1b\n\x13\x63\x61pitalizeFileNames\x18\x06 \x01(\x08\x12\x18\n\x10resampleInterval\x18\x07 \x01(\x01\x12\x19\n\x11\x63onvertCurveUnits\x18\x08 \x01(\x08\"\xa4\x01\n\x1d\x45xportContourMapToTextRequest\x12\x16\n\x0e\x65xportFileName\x18\x01 \x01(\t\x12\x1e\n\x16\x65xportLocalCoordinates\x18\x02 \x01(\x08\x12\x1b\n\x13undefinedValueLabel\x18\x03 \x01(\t\x12\x1e\n\x16\x65xcludeUndefinedValues\x18\x04 \x01(\x08\x12\x0e\n\x06viewId\x18\x05 \x01(\x05\"&\n\x12SaveProjectRequest\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\"\xb1\x12\n\rCommandParams\x12,\n\x0bopenProject\x18\x01 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12#\n\x0c\x63loseProject\x18\x02 \x01(\x0b\x32\x0b.rips.EmptyH\x00\x12,\n\x0bsetStartDir\x18\x03 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12)\n\x08loadCase\x18\x04 \x01(\x0b\x32\x15.rips.FilePathRequestH\x00\x12/\n\x0breplaceCase\x18\x05 \x01(\x0b\x32\x18.rips.ReplaceCaseRequestH\x00\x12=\n\x12replaceSourceCases\x18\x06 \x01(\x0b\x32\x1f.rips.ReplaceSourceCasesRequestH\x00\x12@\n\x18\x65xportMultiCaseSnapshots\x18\x07 \x01(\x0b\x32\x1c.rips.ExportMultiCaseRequestH\x00\x12\x37\n\x0f\x65xportSnapshots\x18\x08 \x01(\x0b\x32\x1c.rips.ExportSnapshotsRequestH\x00\x12\x35\n\x0e\x65xportProperty\x18\t \x01(\x0b\x32\x1b.rips.ExportPropertyRequestH\x00\x12\x43\n\x15\x65xportPropertyInViews\x18\n \x01(\x0b\x32\".rips.ExportPropertyInViewsRequestH\x00\x12\x44\n\x19\x65xportWellPathCompletions\x18\x0b \x01(\x0b\x32\x1f.rips.ExportWellPathCompRequestH\x00\x12N\n exportSimWellFractureCompletions\x18\x0c \x01(\x0b\x32\".rips.ExportSimWellPathFracRequestH\x00\x12+\n\texportMsw\x18\r \x01(\x0b\x32\x16.rips.ExportMswRequestH\x00\x12\x36\n\x0f\x65xportWellPaths\x18\x0e \x01(\x0b\x32\x1b.rips.ExportWellPathRequestH\x00\x12=\n\x12\x65xportVisibleCells\x18\x0f \x01(\x0b\x32\x1f.rips.ExportVisibleCellsRequestH\x00\x12\x37\n\x0fsetExportFolder\x18\x10 \x01(\x0b\x32\x1c.rips.SetExportFolderRequestH\x00\x12\x37\n\x0frunOctaveScript\x18\x11 \x01(\x0b\x32\x1c.rips.RunOctaveScriptRequestH\x00\x12\x36\n\x11setMainWindowSize\x18\x12 \x01(\x0b\x32\x19.rips.SetWindowSizeParamsH\x00\x12G\n\x1a\x63omputeCaseGroupStatistics\x18\x13 \x01(\x0b\x32!.rips.ComputeCaseGroupStatRequestH\x00\x12.\n\x0bsetTimeStep\x18\x14 \x01(\x0b\x32\x17.rips.SetTimeStepParamsH\x00\x12\x43\n\x15scaleFractureTemplate\x18\x15 \x01(\x0b\x32\".rips.ScaleFractureTemplateRequestH\x00\x12\x41\n\x16setFractureContainment\x18\x16 \x01(\x0b\x32\x1f.rips.SetFracContainmentRequestH\x00\x12\x42\n\x17\x63reateMultipleFractures\x18\x17 \x01(\x0b\x32\x1f.rips.CreateMultipleFracRequestH\x00\x12@\n\x17\x63reateLgrForCompletions\x18\x18 \x01(\x0b\x32\x1d.rips.CreateLgrForCompRequestH\x00\x12H\n\x1d\x63reateSaturationPressurePlots\x18\x19 \x01(\x0b\x32\x1f.rips.CreateSatPressPlotRequestH\x00\x12\x39\n\x14replaceMultipleCases\x18\x1a \x01(\x0b\x32\x19.rips.ReplaceCaseRequestsH\x00\x12?\n\x13\x63reateGridCaseGroup\x18\x1b \x01(\x0b\x32 .rips.CreateGridCaseGroupRequestH\x00\x12\x41\n\x14\x63reateStatisticsCase\x18\x1c \x01(\x0b\x32!.rips.CreateStatisticsCaseRequestH\x00\x12@\n\x19\x65xportFlowCharacteristics\x18\x1d \x01(\x0b\x32\x1b.rips.ExportFlowInfoRequestH\x00\x12-\n\ncreateView\x18\x1e \x01(\x0b\x32\x17.rips.CreateViewRequestH\x00\x12+\n\tcloneView\x18\x1f \x01(\x0b\x32\x16.rips.CloneViewRequestH\x00\x12\x41\n\x1b\x63reateWellBoreStabilityPlot\x18  \x01(\x0b\x32\x1a.rips.CreateWbsPlotRequestH\x00\x12\x37\n\x0fimportWellPaths\x18! \x01(\x0b\x32\x1c.rips.ImportWellPathsRequestH\x00\x12=\n\x12importWellLogFiles\x18\" \x01(\x0b\x32\x1f.rips.ImportWellLogFilesRequestH\x00\x12\x41\n\x14importFormationNames\x18# \x01(\x0b\x32!.rips.ImportFormationNamesRequestH\x00\x12\x43\n\x15\x65xportWellLogPlotData\x18$ \x01(\x0b\x32\".rips.ExportWellLogPlotDataRequestH\x00\x12\x36\n\x11setPlotWindowSize\x18% \x01(\x0b\x32\x19.rips.SetWindowSizeParamsH\x00\x12\x45\n\x16\x65xportContourMapToText\x18& \x01(\x0b\x32#.rips.ExportContourMapToTextRequestH\x00\x12/\n\x0bsaveProject\x18\' \x01(\x0b\x32\x18.rips.SaveProjectRequestH\x00\x42\x08\n\x06params\"9\n\x13GridCaseGroupResult\x12\x0f\n\x07groupId\x18\x01 \x01(\x05\x12\x11\n\tgroupName\x18\x02 \x01(\t\",\n\x1a\x43reateStatisticsCaseResult\x12\x0e\n\x06\x63\x61seId\x18\x01 \x01(\x05\"\"\n\x10\x43reateViewResult\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\"%\n\x13\x43reateWbsPlotResult\x12\x0e\n\x06viewId\x18\x01 \x01(\x05\".\n\x15ImportWellPathsResult\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\"1\n\x18ImportWellLogFilesResult\x12\x15\n\rwellPathNames\x18\x01 \x03(\t\"4\n\x1b\x45xportWellLogPlotDataResult\x12\x15\n\rexportedFiles\x18\x01 \x03(\t\"\xab\x04\n\x0c\x43ommandReply\x12\"\n\x0b\x65mptyResult\x18\x01 \x01(\x0b\x32\x0b.rips.EmptyH\x00\x12+\n\x0eloadCaseResult\x18\x02 \x01(\x0b\x32\x11.rips.CaseRequestH\x00\x12>\n\x19\x63reateGridCaseGroupResult\x18\x03 \x01(\x0b\x32\x19.rips.GridCaseGroupResultH\x00\x12\x46\n\x1a\x63reateStatisticsCaseResult\x18\x04 \x01(\x0b\x32 .rips.CreateStatisticsCaseResultH\x00\x12\x32\n\x10\x63reateViewResult\x18\x05 \x01(\x0b\x32\x16.rips.CreateViewResultH\x00\x12\x38\n\x13\x63reateWbsPlotResult\x18\x06 \x01(\x0b\x32\x19.rips.CreateWbsPlotResultH\x00\x12<\n\x15importWellPathsResult\x18\x07 \x01(\x0b\x32\x1b.rips.ImportWellPathsResultH\x00\x12\x42\n\x18importWellLogFilesResult\x18\x08 \x01(\x0b\x32\x1e.rips.ImportWellLogFilesResultH\x00\x12H\n\x1b\x65xportWellLogPlotDataResult\x18\t \x01(\x0b\x32!.rips.ExportWellLogPlotDataResultH\x00\x42\x08\n\x06result*$\n\x10PlotOutputFormat\x12\x07\n\x03PNG\x10\x00\x12\x07\n\x03PDF\x10\x01*-\n\x0cSnapshotType\x12\t\n\x05VIEWS\x10\x00\x12\t\n\x05PLOTS\x10\x01\x12\x07\n\x03\x41LL\x10\x02*`\n\x12\x43ompdatExportSplit\x12\x10\n\x0cUNIFIED_FILE\x10\x00\x12\x11\n\rSPLIT_ON_WELL\x10\x01\x12%\n!SPLIT_ON_WELL_AND_COMPLETION_TYPE\x10\x02*k\n\x11\x43ompdatExportType\x12\x16\n\x12TRANSMISSIBILITIES\x10\x00\x12*\n&WPIMULT_AND_DEFAULT_CONNECTION_FACTORS\x10\x01\x12\x12\n\x0eNO_COMPLETIONS\x10\x02*8\n\x16\x43ompdatCombinationMode\x12\x10\n\x0cINDIVIDUALLY\x10\x00\x12\x0c\n\x08\x43OMBINED\x10\x01*v\n\x10\x45xportFolderType\x12\x0f\n\x0b\x43OMPLETIONS\x10\x00\x12\r\n\tSNAPSHOTS\x10\x01\x12\x0e\n\nPROPERTIES\x10\x02\x12\x0e\n\nSTATISTICS\x10\x03\x12\r\n\tWELLPATHS\x10\x04\x12\t\n\x05\x43\x45LLS\x10\x05\x12\x08\n\x04LGRS\x10\x06*K\n\x12MultipleFracAction\x12\x08\n\x04NONE\x10\x00\x12\x14\n\x10\x41PPEND_FRACTURES\x10\x01\x12\x15\n\x11REPLACE_FRACTURES\x10\x02*J\n\x0cLgrSplitType\x12\x10\n\x0cLGR_PER_CELL\x10\x00\x12\x16\n\x12LGR_PER_COMPLETION\x10\x01\x12\x10\n\x0cLGR_PER_WELL\x10\x02*\"\n\x0c\x45xportFormat\x12\x07\n\x03LAS\x10\x00\x12\t\n\x05\x41SCII\x10\x01\x32@\n\x08\x43ommands\x12\x34\n\x07\x45xecute\x12\x13.rips.CommandParams\x1a\x12.rips.CommandReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Commands_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLOTOUTPUTFORMAT']._serialized_start=7055
  _globals['_PLOTOUTPUTFORMAT']._serialized_end=7091
  _globals['_SNAPSHOTTYPE']._serialized_start=7093
  _globals['_SNAPSHOTTYPE']._serialized_end=7138
  _globals['_COMPDATEXPORTSPLIT']._serialized_start=7140
  _globals['_COMPDATEXPORTSPLIT']._serialized_end=7236
  _globals['_COMPDATEXPORTTYPE']._serialized_start=7238
  _globals['_COMPDATEXPORTTYPE']._serialized_end=7345
  _globals['_COMPDATCOMBINATIONMODE']._serialized_start=7347
  _globals['_COMPDATCOMBINATIONMODE']._serialized_end=7403
  _globals['_EXPORTFOLDERTYPE']._serialized_start=7405
  _globals['_EXPORTFOLDERTYPE']._serialized_end=7523
  _globals['_MULTIPLEFRACACTION']._serialized_start=7525
  _globals['_MULTIPLEFRACACTION']._serialized_end=7600
  _globals['_LGRSPLITTYPE']._serialized_start=7602
  _globals['_LGRSPLITTYPE']._serialized_end=7676
  _globals['_EXPORTFORMAT']._serialized_start=7678
  _globals['_EXPORTFORMAT']._serialized_end=7712
  _globals['_FILEPATHREQUEST']._serialized_start=72
  _globals['_FILEPATHREQUEST']._serialized_end=121
  _globals['_REPLACECASEREQUEST']._serialized_start=123
  _globals['_REPLACECASEREQUEST']._serialized_end=180
  _globals['_REPLACECASEREQUESTS']._serialized_start=182
  _globals['_REPLACECASEREQUESTS']._serialized_end=248
  _globals['_REPLACESOURCECASESREQUEST']._serialized_start=250
  _globals['_REPLACESOURCECASESREQUEST']._serialized_end=320
  _globals['_EXPORTMULTICASEREQUEST']._serialized_start=322
  _globals['_EXPORTMULTICASEREQUEST']._serialized_end=368
  _globals['_EXPORTSNAPSHOTSREQUEST']._serialized_start=371
  _globals['_EXPORTSNAPSHOTSREQUEST']._serialized_end=549
  _globals['_EXPORTPROPERTYREQUEST']._serialized_start=552
  _globals['_EXPORTPROPERTYREQUEST']._serialized_end=695
  _globals['_EXPORTPROPERTYINVIEWSREQUEST']._serialized_start=697
  _globals['_EXPORTPROPERTYINVIEWSREQUEST']._serialized_end=784
  _globals['_EXPORTWELLPATHCOMPREQUEST']._serialized_start=787
  _globals['_EXPORTWELLPATHCOMPREQUEST']._serialized_end=1182
  _globals['_EXPORTSIMWELLPATHFRACREQUEST']._serialized_start=1185
  _globals['_EXPORTSIMWELLPATHFRACREQUEST']._serialized_end=1387
  _globals['_EXPORTMSWREQUEST']._serialized_start=1389
  _globals['_EXPORTMSWREQUEST']._serialized_end=1441
  _globals['_EXPORTWELLPATHREQUEST']._serialized_start=1443
  _globals['_EXPORTWELLPATHREQUEST']._serialized_end=1509
  _globals['_EXPORTVISIBLECELLSREQUEST']._serialized_start=1512
  _globals['_EXPORTVISIBLECELLSREQUEST']._serialized_end=1687
  _globals['_SETEXPORTFOLDERREQUEST']._serialized_start=1689
  _globals['_SETEXPORTFOLDERREQUEST']._serialized_end=1787
  _globals['_RUNOCTAVESCRIPTREQUEST']._serialized_start=1789
  _globals['_RUNOCTAVESCRIPTREQUEST']._serialized_end=1844
  _globals['_SETWINDOWSIZEPARAMS']._serialized_start=1846
  _globals['_SETWINDOWSIZEPARAMS']._serialized_end=1898
  _globals['_COMPUTECASEGROUPSTATREQUEST']._serialized_start=1900
  _globals['_COMPUTECASEGROUPSTATREQUEST']._serialized_end=1967
  _globals['_SETTIMESTEPPARAMS']._serialized_start=1969
  _globals['_SETTIMESTEPPARAMS']._serialized_end=2038
  _globals['_SCALEFRACTURETEMPLATEREQUEST']._serialized_start=2040
  _globals['_SCALEFRACTURETEMPLATEREQUEST']._serialized_end=2118
  _globals['_SETFRACCONTAINMENTREQUEST']._serialized_start=2120
  _globals['_SETFRACCONTAINMENTREQUEST']._serialized_end=2196
  _globals['_CREATEMULTIPLEFRACREQUEST']._serialized_start=2199
  _globals['_CREATEMULTIPLEFRACREQUEST']._serialized_end=2437
  _globals['_CREATELGRFORCOMPREQUEST']._serialized_start=2440
  _globals['_CREATELGRFORCOMPREQUEST']._serialized_end=2624
  _globals['_CREATESATPRESSPLOTREQUEST']._serialized_start=2626
  _globals['_CREATESATPRESSPLOTREQUEST']._serialized_end=2670
  _globals['_CREATEGRIDCASEGROUPREQUEST']._serialized_start=2672
  _globals['_CREATEGRIDCASEGROUPREQUEST']._serialized_end=2719
  _globals['_CREATESTATISTICSCASEREQUEST']._serialized_start=2721
  _globals['_CREATESTATISTICSCASEREQUEST']._serialized_end=2771
  _globals['_EXPORTFLOWINFOREQUEST']._serialized_start=2774
  _globals['_EXPORTFLOWINFOREQUEST']._serialized_end=2948
  _globals['_CREATEVIEWREQUEST']._serialized_start=2950
  _globals['_CREATEVIEWREQUEST']._serialized_end=2985
  _globals['_CLONEVIEWREQUEST']._serialized_start=2987
  _globals['_CLONEVIEWREQUEST']._serialized_end=3021
  _globals['_CREATEWBSPLOTREQUEST']._serialized_start=3023
  _globals['_CREATEWBSPLOTREQUEST']._serialized_end=3137
  _globals['_IMPORTWELLPATHSREQUEST']._serialized_start=3139
  _globals['_IMPORTWELLPATHSREQUEST']._serialized_end=3210
  _globals['_IMPORTWELLLOGFILESREQUEST']._serialized_start=3212
  _globals['_IMPORTWELLLOGFILESREQUEST']._serialized_end=3284
  _globals['_IMPORTFORMATIONNAMESREQUEST']._serialized_start=3286
  _globals['_IMPORTFORMATIONNAMESREQUEST']._serialized_end=3362
  _globals['_EXPORTWELLLOGPLOTDATAREQUEST']._serialized_start=3365
  _globals['_EXPORTWELLLOGPLOTDATAREQUEST']._serialized_end=3599
  _globals['_EXPORTCONTOURMAPTOTEXTREQUEST']._serialized_start=3602
  _globals['_EXPORTCONTOURMAPTOTEXTREQUEST']._serialized_end=3766
  _globals['_SAVEPROJECTREQUEST']._serialized_start=3768
  _globals['_SAVEPROJECTREQUEST']._serialized_end=3806
  _globals['_COMMANDPARAMS']._serialized_start=3809
  _globals['_COMMANDPARAMS']._serialized_end=6162
  _globals['_GRIDCASEGROUPRESULT']._serialized_start=6164
  _globals['_GRIDCASEGROUPRESULT']._serialized_end=6221
  _globals['_CREATESTATISTICSCASERESULT']._serialized_start=6223
  _globals['_CREATESTATISTICSCASERESULT']._serialized_end=6267
  _globals['_CREATEVIEWRESULT']._serialized_start=6269
  _globals['_CREATEVIEWRESULT']._serialized_end=6303
  _globals['_CREATEWBSPLOTRESULT']._serialized_start=6305
  _globals['_CREATEWBSPLOTRESULT']._serialized_end=6342
  _globals['_IMPORTWELLPATHSRESULT']._serialized_start=6344
  _globals['_IMPORTWELLPATHSRESULT']._serialized_end=6390
  _globals['_IMPORTWELLLOGFILESRESULT']._serialized_start=6392
  _globals['_IMPORTWELLLOGFILESRESULT']._serialized_end=6441
  _globals['_EXPORTWELLLOGPLOTDATARESULT']._serialized_start=6443
  _globals['_EXPORTWELLLOGPLOTDATARESULT']._serialized_end=6495
  _globals['_COMMANDREPLY']._serialized_start=6498
  _globals['_COMMANDREPLY']._serialized_end=7053
  _globals['_COMMANDS']._serialized_start=7714
  _globals['_COMMANDS']._serialized_end=7778
# @@protoc_insertion_point(module_scope)
