# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import Definitions_pb2 as Definitions__pb2
import Grid_pb2 as Grid__pb2


class GridStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCellCenters = channel.unary_stream(
                '/rips.Grid/GetCellCenters',
                request_serializer=Grid__pb2.GridRequest.SerializeToString,
                response_deserializer=Definitions__pb2.CellCenters.FromString,
                )
        self.GetCellCorners = channel.unary_stream(
                '/rips.Grid/GetCellCorners',
                request_serializer=Grid__pb2.GridRequest.SerializeToString,
                response_deserializer=Definitions__pb2.CellCornersArray.FromString,
                )
        self.GetDimensions = channel.unary_unary(
                '/rips.Grid/GetDimensions',
                request_serializer=Grid__pb2.GridRequest.SerializeToString,
                response_deserializer=Grid__pb2.GridDimensions.FromString,
                )


class GridServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCellCenters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCellCorners(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDimensions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GridServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCellCenters': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCellCenters,
                    request_deserializer=Grid__pb2.GridRequest.FromString,
                    response_serializer=Definitions__pb2.CellCenters.SerializeToString,
            ),
            'GetCellCorners': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCellCorners,
                    request_deserializer=Grid__pb2.GridRequest.FromString,
                    response_serializer=Definitions__pb2.CellCornersArray.SerializeToString,
            ),
            'GetDimensions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDimensions,
                    request_deserializer=Grid__pb2.GridRequest.FromString,
                    response_serializer=Grid__pb2.GridDimensions.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rips.Grid', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Grid(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCellCenters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Grid/GetCellCenters',
            Grid__pb2.GridRequest.SerializeToString,
            Definitions__pb2.CellCenters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCellCorners(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rips.Grid/GetCellCorners',
            Grid__pb2.GridRequest.SerializeToString,
            Definitions__pb2.CellCornersArray.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDimensions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rips.Grid/GetDimensions',
            Grid__pb2.GridRequest.SerializeToString,
            Grid__pb2.GridDimensions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
