#
#  Copyright (C) 2019- Equinor ASA
# 
#  ResInsight is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
# 
#  ResInsight is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or
#  FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See the GNU General Public License at <http://www.gnu.org/licenses/gpl.html> 
#  for more details.
#
#  Python version of RiaVersionInfo.h
#  Just sets version constants

RESINSIGHT_MAJOR_VERSION = "2023"
RESINSIGHT_MINOR_VERSION = "06"
RESINSIGHT_PATCH_VERSION = "0"
